@@ -323,13 +323,13 @@ def measure_network(nidb):
     remote_hosts = [node.tap.ip for node in nidb.nodes("is_router")]
     dest_node = random.choice([n for n in nidb.nodes("is_l3device")])
     log.info("Tracing to randomly selected node: %s" % dest_node)
-    dest_ip = dest_node.interfaces[
-        0].ip_address  # choose random interface on this node
+    dest_ip = dest_node.interfaces[0].ipv4_address  # choose random interface on this node
 
     command = "traceroute -n -a -U -w 0.5 %s" % dest_ip
+    measure.send(nidb, command, remote_hosts, threads = 10)
     # abort after 10 fails, proceed on any success, 0.1 second timeout (quite aggressive)
-    # command = 'vtysh -c "show ip route"'
-    measure.send(nidb, "measure_client", command, remote_hosts)
+    #command = 'vtysh -c "show ip route"'
+    #measure.send(nidb, command, remote_hosts, threads = 5)
     remote_hosts = [node.tap.ip for node in nidb.nodes(
         "is_router") if node.bgp.ebgp_neighbors]
     command = "cat /var/log/zebra/bgpd.log"
