@@ -126,8 +126,22 @@ class MyWebHandler(tornado.web.RequestHandler):
         elif "path" in body_parsed:
             #TODO: check if need to write_message to listeners
             self.update_listeners(data) # could do extra processing here
+#TODO: check if update_listeners is working correctly, why do need next line?
+            for listener in self.application.socket_listeners:
+                listener.write_message(data) 
+        elif "starting" in body_parsed:
+            #TODO: check if need to write_message to listeners
+            self.update_listeners(data) # could do extra processing here
+#TODO: check if update_listeners is working correctly, why do need next line?
+            for listener in self.application.socket_listeners:
+                listener.write_message(data) 
+        elif "lab started" in body_parsed:
+            #TODO: check if need to write_message to listeners
+            self.update_listeners(data) # could do extra processing here
+#TODO: check if update_listeners is working correctly, why do need next line?
+            for listener in self.application.socket_listeners:
+                listener.write_message(data) 
         elif "highlight" in body_parsed:
-            print "Received highlight data"
             self.update_listeners(data) # could do extra processing here
             #TODO check why need to do following - should be automatic for update_listeners?
             for listener in self.application.socket_listeners:
